@@ -121,9 +121,9 @@ def processor(d_df, df_master, ssp_df, wacgu_dict, fy_year, month_dict):
 
         inventory_dict[month] = pd.DataFrame(stock_list)
 
-        # Logic to save info by deal reference
+        # Logic to save info by Counterparty Code
         # get the deal refs
-        deal_refs = set(df_master['DealRef'])
+        deal_refs = set(df_master['Counterpart'])
 
         sub_deal_dict = {}
 
@@ -135,7 +135,7 @@ def processor(d_df, df_master, ssp_df, wacgu_dict, fy_year, month_dict):
 
             for deal in deal_refs:
                 stock_dict = {'DealRef': deal}
-                stock_data = df[df['DealRef'] == deal]
+                stock_data = df[df['Counterpart'] == deal]
 
                 stock_dict.update(calculate_stock_info(stock_data))
                 stock_list.append(stock_dict)
@@ -150,7 +150,7 @@ def processor(d_df, df_master, ssp_df, wacgu_dict, fy_year, month_dict):
 
                 for deal in deal_refs:
                     stock_dict_business = {'DealRef': deal}
-                    stock_data_business = df_business_line[df_business_line['DealRef'] == deal]
+                    stock_data_business = df_business_line[df_business_line['Counterpart'] == deal]
                     # getting the information for opening inventory
                     stock_dict_business.update(calculate_sales(stock_data_business))
                     stock_list_business.append(stock_dict_business)
@@ -233,7 +233,7 @@ inv_last_buy_price = get_last_buy_price(inv_master_df)
 # main wrapper function
 
 def main_execute():
-    print('Package run 34 executing...')
+    print('Package run 40 executing...')
 
     # collect the base tables
     base_table_2020, base_table_2020_Inv, base_table_2020_Deal = processor(dict_df, master_df, ssp_df, wacgu_dict,
